@@ -172,12 +172,13 @@ def python_type_to_graphql_type(t, nonnull=True):
         assert len(t.__args__) == 1
         return GraphQLList(python_type_to_graphql_type(t.__args__[0], nonnull=True))
     elif str(t).startswith("typing.Tuple"):
-        assert len(t.__args__) == 1
+        if not len(set(t.__args__)) == 1:
+            raise Exception("tuples must have the same type for all members")
         return GraphQLList(python_type_to_graphql_type(t.__args__[0], nonnull=True))
     if str(t).startswith("graphql.type.definition.GraphQLList"):
         assert len(t.__args__) == 1
         return GraphQLList(python_type_to_graphql_type(t.__args__[0], nonnull=True))
-    elif str(t).startswith("typing.Union"):
+    elif str(t).startswith("typing.Union") or str(t).startswith("typing.Optional"):
         if len(t.__args__) == 2:
             if issubclass(t.__args__[1], type(None)):
                 return python_type_to_graphql_type(t.__args__[0], nonnull=False)
@@ -191,38 +192,43 @@ def python_type_to_graphql_type(t, nonnull=True):
             return GraphQLNonNull(t)
         return t
 
-    elif issubclass(t, TypedInputGraphQLObject):
-        if nonnull:
-            return GraphQLNonNull(t.graphql_type)
-        return t.graphql_type
-    elif issubclass(t, TypedGraphQLObject):
-        if nonnull:
-            return GraphQLNonNull(t.graphql_type)
-        return t.graphql_type
-    elif issubclass(t, str):
-        if nonnull:
-            return GraphQLNonNull(String)
-        return String
-    elif issubclass(t, bool):
-        if nonnull:
-            return GraphQLNonNull(Boolean)
-        return Boolean
-    elif issubclass(t, int):
-        if nonnull:
-            return GraphQLNonNull(Int)
-        return Int
-    elif issubclass(t, float):
-        if nonnull:
-            return GraphQLNonNull(Float)
-        return Float
-    elif issubclass(t, enum.Enum):
-        if not hasattr(t, "_graphql_type"):
-            t._graphql_type = GraphQLEnumType(
-                t.__name__,
-                dict(t.__members__)
-            )
-        if nonnull:
-            return GraphQLNonNull(t._graphql_type)
-        return t._graphql_type
     else:
-        raise Exception(t)
+        try:
+            if issubclass(t, TypedInputGraphQLObject):
+                if nonnull:
+                    return GraphQLNonNull(t.graphql_type)
+                return t.graphql_type
+            elif issubclass(t, TypedGraphQLObject):
+                if nonnull:
+                    return GraphQLNonNull(t.graphql_type)
+                return t.graphql_type
+            elif issubclass(t, str):
+                if nonnull:
+                    return GraphQLNonNull(String)
+                return String
+            elif issubclass(t, bool):
+                if nonnull:
+                    return GraphQLNonNull(Boolean)
+                return Boolean
+            elif issubclass(t, int):
+                if nonnull:
+                    return GraphQLNonNull(Int)
+                return Int
+            elif issubclass(t, float):
+                if nonnull:
+                    return GraphQLNonNull(Float)
+                return Float
+            elif issubclass(t, enum.Enum):
+                if not hasattr(t, "_graphql_type"):
+                    t._graphql_type = GraphQLEnumType(
+                        t.__name__,
+                        dict(t.__members__)
+                    )
+                if nonnull:
+                    return GraphQLNonNull(t._graphql_type)
+                return t._graphql_type
+            else:
+                raise Exception(t)
+        except TypeError:
+            print(f"Bad type: {t} of {type(t)}")
+            raise
